Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthieu Aubry <mattab@users.noreply.github.com>2021-01-08 05:48:58 +0300
committerGitHub <noreply@github.com>2021-01-08 05:48:58 +0300
commit29d9af0f50ac3a22895f43bdd5724724c058b8ce (patch)
tree0e6fc2b2e3866d3f4a62d8a9ec9e547d961d4150 /misc/others
parentb825793104f426f52c09ad266715fccc64cb2f96 (diff)
Rename piwik to matomo in uninstall script (#17061)
Diffstat (limited to 'misc/others')
-rw-r--r--misc/others/uninstall-delete-matomo-directory.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/misc/others/uninstall-delete-matomo-directory.php b/misc/others/uninstall-delete-matomo-directory.php
index 9d81e831aa..172cdfcba9 100644
--- a/misc/others/uninstall-delete-matomo-directory.php
+++ b/misc/others/uninstall-delete-matomo-directory.php
@@ -1,14 +1,14 @@
<?php
exit; // Remove this line before using the script
// How to remove the piwik/ directory if it does not work in FTP?
// 1) Download and upload this file to your webserver
// 2) Remove the 2nd line (the "exit;")
// 3) Put this file in the folder that contains the piwik/ directory (above the piwik/ directory)
// For example if the piwik/ folder is at http://your-site/piwik/ you put the file in http://your-site/uninstall-delete-piwik-directory.php
// 4) Go with your browser to http://your-site/uninstall-delete-piwik-directory.php
// 5) The folder http://your-site/piwik/ should now be deleted!
// We hope you enjoyed Piwik. If you have any feedback why you stopped using Piwik,
// please let us know at hello@matomo.org - we are interested by your experience
function unlinkRecursive($dir)
{
@@ -26,4 +26,4 @@ function unlinkRecursive($dir)
return "Folder $dir deleted!";
}
-echo unlinkRecursive('piwik/');
+echo unlinkRecursive('matomo/');
@@ -1,14 +1,14 @@
<?php
exit; // Remove this line before using the script
-// How to remove the piwik/ directory if it does not work in FTP?
+// How to remove the matomo/ directory if it does not work in FTP?
// 1) Download and upload this file to your webserver
// 2) Remove the 2nd line (the "exit;")
@@ -1,14 +1,14 @@
// 1) Download and upload this file to your webserver
// 2) Remove the 2nd line (the "exit;")
-// 3) Put this file in the folder that contains the piwik/ directory (above the piwik/ directory)
-// For example if the piwik/ folder is at http://your-site/piwik/ you put the file in http://your-site/uninstall-delete-piwik-directory.php
-// 4) Go with your browser to http://your-site/uninstall-delete-piwik-directory.php
-// 5) The folder http://your-site/piwik/ should now be deleted!
-// We hope you enjoyed Piwik. If you have any feedback why you stopped using Piwik,
+// 3) Put this file in the folder that contains the matomo/ directory (above the matomo/ directory)
+// For example if the matomo/ folder is at http://your-site/matomo/ you put the file in http://your-site/uninstall-delete-matomo-directory.php
+// 4) Go with your browser to http://your-site/uninstall-delete-matomo-directory.php
+// 5) The folder http://your-site/matomo/ should now be deleted!
+// We hope you enjoyed Matomo. If you have any feedback why you stopped using Matomo,
// please let us know at hello@matomo.org - we are interested by your experience
function unlinkRecursive($dir)